@@ -3,7 +3,7 @@ import requests
 
 class BaseClient(object):
     def __init__(self, token):
-        from version import __version__
+        from .version import __version__
 
         self.token = token
         self.version = __version__
@@ -24,8 +24,6 @@ class BaseClient(object):
 
             result = response.json()
 
-            print(result)
-
             if result.get("status_code", None) is not None:
                 return default_value
 
@@ -36,5 +34,5 @@ class BaseClient(object):
 
     def _perform_request(self, data):
         return requests.post(
-            "http://api.orquesta.dev/evaluate/", headers=self.headers, json=data
+            "https://api.orquesta.dev/evaluate/", headers=self.headers, json=data
         )
